.. _spkg_types_python_dateutil:

types_python_dateutil: Typing stubs for python-dateutil
=======================================================

Description
-----------

Typing stubs for python-dateutil

License
-------

Apache-2.0 license

Upstream Contact
----------------

https://pypi.org/project/types-python-dateutil/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.9.0.20240316

version_requirements.txt::

    types-python-dateutil

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install types-python-dateutil

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i types_python_dateutil

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-types-python-dateutil


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
